#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
    Dummy conftest.py for pygeogrids
# share/my_project/docs = docs/*.

    If you don't know what this is for, just leave it empty.
    Read more about conftest.py under:
    https://pytest.org/latest/plugins.html
"""
from __future__ import print_function, absolute_import, division

import pytest
